@@ -3,7 +3,7 @@ BEGIN {
   $Spreadsheet::ParseXLSX::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Spreadsheet::ParseXLSX::VERSION = '0.04';
+  $Spreadsheet::ParseXLSX::VERSION = '0.05';
 }
 use strict;
 use warnings;
@@ -373,7 +373,7 @@ sub _parse_styles {
         49 => '@',
         (map {
             $_->att('numFmtId') => $_->att('formatCode')
-        } $styles->find_nodes('//numFmt')),
+        } $styles->find_nodes('//numFmts/numFmt')),
     );
 
     my @font = map {
@@ -400,7 +400,7 @@ sub _parse_styles {
             # Underline => $bUnderline,
             # Strikeout => $bStrikeout,
         )
-    } $styles->find_nodes('//font');
+    } $styles->find_nodes('//fonts/font');
 
     my @format = map {
         my $alignment = $_->first_child('alignment');
@@ -618,7 +618,7 @@ Spreadsheet::ParseXLSX - parse XLSX files
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
